@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2023, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -466,7 +466,7 @@ SEXP stri_enc_isenc(SEXP str, int _type)
     }
 
 
-    PROTECT(str = stri_prepare_arg_list_raw(str, "str"));
+    PROTECT(str = stri__prepare_arg_list_raw(str, "str"));
 
     STRI__ERROR_HANDLER_BEGIN(1)
     StriContainerListRaw str_cont(str);
@@ -588,8 +588,8 @@ SEXP stri_enc_isutf32le(SEXP str) {
  */
 SEXP stri_enc_detect(SEXP str, SEXP filter_angle_brackets)
 {
-    PROTECT(str = stri_prepare_arg_list_raw(str, "str"));
-    PROTECT(filter_angle_brackets = stri_prepare_arg_logical(filter_angle_brackets, "filter_angle_brackets"));
+    PROTECT(str = stri__prepare_arg_list_raw(str, "str"));
+    PROTECT(filter_angle_brackets = stri__prepare_arg_logical(filter_angle_brackets, "filter_angle_brackets"));
 
     UCharsetDetector* ucsdet = NULL;
 
@@ -702,7 +702,7 @@ SEXP stri_enc_detect(SEXP str, SEXP filter_angle_brackets)
 // -----------------------------------------------------------------------
 
 
-/** locale-dependent 8-bit converter check
+/** locale-dependent 8-bit converter check  [DEPRECATED]
  *
  * help struct for stri_enc_detect2
  *
@@ -805,7 +805,7 @@ struct Converter8bit {
 // -----------------------------------------------------------------------
 
 
-/** Guesses text encoding; help struct for stri_enc_detect2
+/** Guesses text encoding; help struct for stri_enc_detect2  [DEPRECATED]
  *
  * @version 0.1-?? (Marek Gagolewski)
  *
@@ -986,7 +986,7 @@ struct EncGuess {
 // -----------------------------------------------------------------------
 
 
-/** Detect encoding with initial guess
+/** Detect encoding with initial guess  [DEPRECATED]
  *
  * @param str character or raw vector or a list of raw vectors
  * @param loc locale id
@@ -1008,9 +1008,9 @@ struct EncGuess {
 SEXP stri_enc_detect2(SEXP str, SEXP loc)
 {
     const char* qloc = /* this is R_alloc'ed */
-        stri__prepare_arg_locale(loc, "locale", true, true); // allowdefault, allowna
+        stri__prepare_arg_locale(loc, "locale");
     // raw vector, character vector, or list of raw vectors:
-    PROTECT(str = stri_prepare_arg_list_raw(str, "str"));
+    PROTECT(str = stri__prepare_arg_list_raw(str, "str"));
 
     STRI__ERROR_HANDLER_BEGIN(1)
 
